@@ -49,6 +49,7 @@ use NewsExtractor::SiteSpecificExtractor::www_digitimes_com_tw;
 use NewsExtractor::SiteSpecificExtractor::www_ustv_com_tw;
 use NewsExtractor::SiteSpecificExtractor::www_mdnkids_com;
 use NewsExtractor::SiteSpecificExtractor::www_nownews_com;
+use NewsExtractor::SiteSpecificExtractor::www_penghutimes_com;
 use NewsExtractor::SiteSpecificExtractor::UDN;
 use NewsExtractor::SiteSpecificExtractor::ETtoday;
 use NewsExtractor::SiteSpecificExtractor::ChinaTimes;
@@ -66,6 +67,7 @@ has extractor => (
 
 use constant {
     SiteSpecificExtractorByHost => {
+        'www.penghutimes.com' => 'NewsExtractor::SiteSpecificExtractor::www_penghutimes_com',
         'www.ustv.com.tw' => 'NewsExtractor::SiteSpecificExtractor::www_ustv_com_tw',
         'www.epochtimes.com' => 'NewsExtractor::SiteSpecificExtractor::www_epochtimes_com',
         'www.hkcnews.com' => 'NewsExtractor::SiteSpecificExtractor::www_hkcnews_com',
