@@ -10,6 +10,7 @@ our @EXPORT = (
     'html2text',
     'is_empty',
     'parse_dateline_ymdhms',
+    'reformat_dateline',
 );
 
 sub u($) {
@@ -44,6 +45,28 @@ sub html2text {
     return join "\n\n", @paragraphs;
 }
 
+sub reformat_dateline {
+    my ($text, $offset) = @_;
+    $offset //= '';
+
+    my @t = $text =~ m/([0-9]+)/g;
+    return undef unless 3 <= @t && @t <= 6;
+
+    my $format_date = '%04d-%02d-%02d';
+    my $format_time = '%02d:%02d:%02d';
+
+    if (@t == 3) {
+        my $format = $format_date . '%s';
+        return u(sprintf($format, $t[0], $t[1], $t[2], $offset));
+    }
+
+    $t[5] //= 0;
+    $t[6] //= 0;
+
+    my $format = $format_date . 'T' . $format_time . '%s';
+    return u(sprintf($format, $t[0], $t[1], $t[2], $t[3], $t[4], $t[5], $offset));
+}
+
 sub parse_dateline_ymdhms {
     my ($text, $offset) = @_;
 
